bayespy.inference.vmp.nodes.stochastic.Distribution.plates_to_parent
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Distribution.plates_to_parent